@@ -261,7 +261,7 @@ class BaseSnatch:
         )
 
         # Check Status
-        if data.integration_status in ["SUCCESS", "TIMEOUT", "CONN_ERROR"]:
+        if data.integration_status in ["SUCCESS", "TIMEOUT", "CONN_ERROR", "NO_DATA"]:
             return data
 
         if data.integration_status == "WAITING":
