@@ -1,7 +1,8 @@
 from dataclasses import dataclass
 from typing import Optional, Type
 
-from marshmallow import EXCLUDE, Schema, fields, post_load
+from loguru import logger
+from marshmallow import EXCLUDE, Schema, fields, post_load, pre_load
 
 from snatch.base.data import BaseData
 from snatch.base.data_source import BaseSnatch
@@ -44,12 +45,18 @@ class BoaVistaData(BaseData):
 class BoaVistaSerializer(BaseSchema):
     default_probability = fields.Float(allow_none=True)
     score = fields.Integer(allow_none=True)
-    total_debts: fields.Float(allow_none=True)
+    total_debts = fields.Float(allow_none=True)
     tax_id_status = fields.Str(allow_none=True)
     payload = fields.Dict(allow_none=True)
 
+    @pre_load
+    def log_received_data(self, data, **kwargs):
+        logger.debug(f"Request Data received is: {data}")
+        return data
+
     @post_load
     def make_data(self, data, **kwargs):
+        logger.debug(f"Deserialized Data received is: {data}")
         new_data = BoaVistaData(**data)
         new_data.datasource_base_url = BoaVista.base_url
         return new_data
